{ Unit: BcTrackBar
  ===========================================================================

  The contents of this file are subject to the Bluecave Limited License V 1.0
  (the "License"). You may not copy or use this file, in either source code
  or executable form, except in compliance with the License. You may obtain
  a copy of the License at http://www.bluecave.net/licenses/.

  Software distributed under the License is distributed on an "AS IS" basis,
  WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
  for the specific language governing rights and limitations under the
  License.

  Copyright (C) 2001-2002 Bluecave Software. All Rights Reserved.
  http://www.bluecave.net/

  Copyright (C) 2001-2002 Jouni Airaksinen. All Rights Reserved.
  http://Mintus.Codefield.com/ -- Mintus@Codefield.com

  ===========================================================================

  Unit description:

    Adds property which allows to disable selection range from the
    trackbar. This will affect the visual appearance of the trackbar
    so that it won't have the white line in the track line.

    property SelRangeEnabled: Boolean

  History:

    2001-11-11: Initial version

  =========================================================================== }

{$I DFS.inc}
{$I BcDirectives.inc}

unit BcTrackBar;

interface

uses
  Windows, Messages, SysUtils, Classes, Controls, ComCtrls;

const
  DefaultSelRangeEnabled = True;

type
  TBcTrackBar = class(TTrackBar)
  private
    FSelRangeEnabled: Boolean;
    procedure SetSelRangeEnabled(const Value: Boolean);
    { Private declarations }
  protected
    { Protected declarations }
  public
    { Public declarations }
    constructor Create(AOwner: TComponent); override;
    procedure CreateParams(var Params: TCreateParams); override;
  published
    { Published declarations }
    property SelRangeEnabled: Boolean read FSelRangeEnabled write SetSelRangeEnabled default DefaultSelRangeEnabled;
  end;

implementation

{ TBcTrackBar }

uses CommCtrl;

constructor TBcTrackBar.Create(AOwner: TComponent);
begin
  FSelRangeEnabled := DefaultSelRangeEnabled;
  inherited Create(AOwner);
end;

procedure TBcTrackBar.CreateParams(var Params: TCreateParams);
begin
  inherited CreateParams(Params);
  if not FSelRangeEnabled then
    Params.Style := Params.Style and not TBS_ENABLESELRANGE;
end;

procedure TBcTrackBar.SetSelRangeEnabled(const Value: Boolean);
begin
  if FSelRangeEnabled <> Value then
  begin
    FSelRangeEnabled := Value;
    RecreateWnd;
  end;
end;

end.
